==> highd-compose-2021.1.4-sources.jar: commonMain/com/macrofocus/high_d/distributions/AbstractDistributions.kt <==
/*
 * Copyright (c) 2016 Macrofocus GmbH. All Rights Reserved.
 */
package com.macrofocus.high_d.distributions

import com.macrofocus.license.LicenseModel
import org.molap.dataframe.DataFrame

abstract class AbstractDistributions<Row, Column, Value, Bin> :
    Distributions<Row, Column, Value, Bin> {
    override var model: DistributionsModel<Row, Column, Value, Bin>? = null
        set(value) {
            if (field !== value) {
                field = value

                // Register it to the current view
                view?.model = value
            }
        }

    override var view: DistributionsView<Row, Column, Value, Bin>? = null
        set(value) {
            if (field !== value) {
                // Deregister the current view
                field?.model = null
                field = value
                if (value != null) {
                    value.model = model
                    field!!.setLicenseModel(licenseModel)
                }
            }
        }

    override var controller: DistributionsController<Row, Column, Value, Bin>? = null
        set(value) {
            if (field !== value) {
                field?.view = null
                field = value
                if (value != null) {
                    value.view = view
                }
            }
        }
    /**
     * Loads the specified data frame.
     *
     * @param dataFrame a data frame
     */
    protected fun load(dataFrame: DataFrame<*,*,*>?) {
        model = createModel(dataFrame)
    }

    /**
     * Creates a model that can be used by the parallel coordinates component
     *
     * @param dataFrame a Swing TableModel
     *
     * @return a DistributionsModel instance
     */
    protected abstract fun createModel(dataFrame: DataFrame<*,*,*>?): DistributionsModel<Row, Column, Value, Bin>

    /**
     * Creates a view that can be used by the parallel coordinates component
     *
     * @return a DistributionsView instance
     */
    protected abstract fun createView(): DistributionsView<Row, Column, *, *>?

    /**
     * Creates a controller that can be used by the parallel coordinates component
     *
     * @param view the view that should be controlled
     *
     * @return a DistributionsController instance
     */
    protected abstract fun createController(view: DistributionsView<*, *, *, *>?): DistributionsController<*, *, *, *>?

    companion object {
        protected var licenseModel: LicenseModel? = null

        /**
         * Register the license key that legally entitle the use of Distributions. This should be called prior to the
         * first instantiation of this component.
         *
         * @param username the user name
         * @param key      the license key
         */
        fun setLicenseKey(username: String?, key: String?) {
//            licenseModel = SimpleLicenseModel(ApplicationModelFactory.HIGHD_API_V1, username, key)
        }
    }
}

==> highd-compose-2025.0.4-sources.jar: commonMain/com/macrofocus/high_d/distributions/AbstractDistributions.kt <==
/*
 * Copyright (c) 2016 Macrofocus GmbH. All Rights Reserved.
 */
package com.macrofocus.high_d.distributions

import com.macrofocus.license.LicenseModel
import org.molap.dataframe.DataFrame

abstract class AbstractDistributions<Row, Column, Value, Bin> :
    Distributions<Row, Column, Value, Bin> {
    override var model: DistributionsModel<Row, Column, Value, Bin>? = null
        set(value) {
            if (field !== value) {
                field = value

                // Register it to the current view
                view?.model = value
            }
        }

    override var view: DistributionsView<Row, Column, Value, Bin>? = null
        set(value) {
            if (field !== value) {
                // Deregister the current view
                field?.model = null
                field = value
                if (value != null) {
                    value.model = model
                    field!!.setLicenseModel(licenseModel)
                }
            }
        }

    override var controller: DistributionsController<Row, Column, Value, Bin>? = null
        set(value) {
            if (field !== value) {
                field?.view = null
                field = value
                if (value != null) {
                    value.view = view
                }
            }
        }
    /**
     * Loads the specified data frame.
     *
     * @param dataFrame a data frame
     */
    protected fun load(dataFrame: DataFrame<Row, Column,Value>?) {
        model = createModel(dataFrame)
    }

    /**
     * Creates a model that can be used by the parallel coordinates component
     *
     * @param dataFrame a Swing TableModel
     *
     * @return a DistributionsModel instance
     */
    protected abstract fun createModel(dataFrame: DataFrame<Row, Column, Value>?): DistributionsModel<Row, Column, Value, Bin>

    /**
     * Creates a view that can be used by the parallel coordinates component
     *
     * @return a DistributionsView instance
     */
    protected abstract fun createView(): DistributionsView<Row, Column, *, *>?

    /**
     * Creates a controller that can be used by the parallel coordinates component
     *
     * @param view the view that should be controlled
     *
     * @return a DistributionsController instance
     */
    protected abstract fun createController(view: DistributionsView<*, *, *, *>?): DistributionsController<*, *, *, *>?

    companion object {
        protected var licenseModel: LicenseModel? = null

        /**
         * Register the license key that legally entitle the use of Distributions. This should be called prior to the
         * first instantiation of this component.
         *
         * @param username the user name
         * @param key      the license key
         */
        fun setLicenseKey(username: String?, key: String?) {
//            licenseModel = SimpleLicenseModel(ApplicationModelFactory.HIGHD_API_V1, username, key)
        }
    }
}
